==> wikitty-api-3.7-test-sources.jar: org/nuiton/wikitty/test/ProductDocumentationHelper.java <==
package org.nuiton.wikitty.test;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class ProductDocumentationHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private ProductDocumentationHelper() {// empty
}

    public static String getDocumentation(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION);
        return value;
}

    public static String setDocumentation(Wikitty wikitty, String documentation) {
        String oldValue = getDocumentation(wikitty);
        wikitty.setField(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION, documentation);
        return oldValue;
}

    public static int getPrice(Wikitty wikitty) {
        int value = wikitty.getFieldAsInt(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE);
        return value;
}

    public static int setPrice(Wikitty wikitty, int price) {
        int oldValue = getPrice(wikitty);
        wikitty.setField(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE, price);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION);
            Object f2 = w2.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE);
            Object f2 = w2.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(ProductDocumentation.EXT_PRODUCTDOCUMENTATION);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : ProductDocumentationAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(ProductDocumentation.EXT_PRODUCTDOCUMENTATION);
}

} //ProductDocumentationHelper

==> wikitty-api-3.10-test-sources.jar: org/nuiton/wikitty/test/ProductDocumentationHelper.java <==
package org.nuiton.wikitty.test;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class ProductDocumentationHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private ProductDocumentationHelper() {// empty
}

    public static String getDocumentation(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION);
        return value;
}

    public static String setDocumentation(Wikitty wikitty, String documentation) {
        String oldValue = getDocumentation(wikitty);
        wikitty.setField(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION, documentation);
        return oldValue;
}

    public static int getPrice(Wikitty wikitty) {
        int value = wikitty.getFieldAsInt(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE);
        return value;
}

    public static int setPrice(Wikitty wikitty, int price) {
        int oldValue = getPrice(wikitty);
        wikitty.setField(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE, price);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION);
            Object f2 = w2.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE);
            Object f2 = w2.getFieldAsObject(ProductDocumentation.EXT_PRODUCTDOCUMENTATION, ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(ProductDocumentation.EXT_PRODUCTDOCUMENTATION);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : ProductDocumentationAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * supprime les extensions de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void removeExtension(Wikitty wikitty) {
        for (WikittyExtension ext : ProductDocumentationAbstract.extensions) {
            wikitty.removeExtension(ext.getName());
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(ProductDocumentation.EXT_PRODUCTDOCUMENTATION);
}

} //ProductDocumentationHelper
